* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim=' ' spool;											
* Kill default titles on output, ODS tables in log; 
TITLE; ODS TRACE OFF;
* THIS TELLS SAS WHERE THE WINDOWS FONTS ARE FOR USE WITH PLOTS;
PROC FONTREG MODE=ALL; FONTPATH "C:\WINDOWS\Fonts\"; RUN;

* Location for original SAS files for these models  change this path;
%LET example = F:\Example Data\Chapter 6 Data\CHAP Burst 1 RT;
LIBNAME example "&example.";
* Defining macro variable for datafile name to be replaced in code below;
%LET datafile=Example7a;

* Bringing data into work library and recoding/centering variables;
* Centering time at different points for polynomial models;
DATA &datafile.; SET example.&datafile.; 
	* Centering time at session 1 or 6 for polynomial models;
	c1sess = session - 1; c6sess = session - 6;
	LABEL c1sess = "Session (0=1)" c6sess = "Session (0=6)";
	* Creating two slopes for piecewise models;
	     IF Session = 1 THEN DO; Slope12 = 0; Slope26 = 0; END;
	ELSE IF Session = 2 THEN DO; Slope12 = 1; Slope26 = 0; END;
	ELSE IF Session > 2 THEN DO; Slope12 = 1; Slope26 = Session-2; END;
	LABEL Slope12 = "1-2 Early Practice Slope"
	      Slope26 = "2-6 Later Practice Slope";
	* Centering level-2 predictors;
	Age80  = baseage - 80; 
	Reas22 = AbsReas - 22;			
	LABEL Age80  = "Age Centered (0=80)" 
	      Reas22 = "Abstract Reasoning Centered (0=22)"; 
	* Make education a grouping variable FOR DEMO PURPOSES;
		 IF EducYrs = . THEN EducGrp = .;
	ELSE IF EducYrs LE 12                   THEN EducGrp=1;
	ELSE IF EducYrs GT 12 AND EducYrs LE 16 THEN EducGrp=2;
	ELSE IF EducYrs GT 16                   THEN EducGrp=3;
	LABEL EducGrp= "Education Group (1=HS, 2=BA, 3=GRAD)";
RUN;

* REMOVING CASES WITH MISSING PREDICTORS OR OUTCOME;
DATA trimmed; SET &datafile.;
	WHERE NMISS(Age80, Reas22, EducGrp, session, nm3rt)=0; RUN;

* Changing dataset used in analyses below;
%LET datafile=trimmed;

**************************************************************************
*****		Sending tables of descriptives to excel worksheet		******
**************************************************************************;
* Send all results to this excel file;
ODS HTML FILE="&example.\Example7a Descriptive Tables.xls" STYLE=MINIMAL;

* Here is an example of how to get descriptive statistics for continuous variables;
* Statistics will be provided per occasion using stacked data;
TITLE "Descriptive Statistics for RT Outcomes - by Session";
PROC MEANS N MIN MAX MEAN STDDEV SKEW KURT DATA=&datafile.; 
	CLASS Session;   	* Print by CLASS variable;
	VAR nm3rt nm5rt; 	* Do for variables listed on VAR;
RUN; TITLE;

* Here is an example of how to get cross-tabs for categorical variables;
* Statistics will be provided per occasion using stacked data;
TITLE "Descriptive Statistics for RT Outcomes - by Session";
PROC FREQ DATA=&datafile.; 
	TABLE Session*EducGrp;
RUN; TITLE;

* Close excel file;
ODS HTML CLOSE;

**************************************************************************
*****		Sending plots of variables to word document				******
**************************************************************************;
* Send all results to this rich text file (open in word);
ODS RTF FILE="&example.\Example7a Descriptive Plots.rtf" 
	STARTPAGE=NO STYLE=STATISTICAL BODYTITLE;

* Here is an example of how to get histograms using stacked data;
* Remove the NOPRINT to get more information per variable, not just plots;
TITLE "Histograms for RT Outcomes";
PROC UNIVARIATE NOPRINT DATA=&datafile.; 
	VAR nm3rt nm5rt; 	* Do for variables listed on VAR;
	HISTOGRAM nm3rt nm5rt;	* Make plots for these variables;
RUN; TITLE;

* Setting system options for graphics below;
GOPTIONS NOBORDER FTEXT="Times New Roman" FTITLE="Times New Roman" VSIZE=5.5in HSIZE=6.0in INTERPOL=JOIN;

* Generating spaghetti plots of change over time for INDIVIDUALS;
TITLE1 JUSTIFY=CENTER HEIGHT=12pt "Change over Sessions in RT"; 
PROC GPLOT DATA=&datafile.; 
* Settings for Y-axis (differ by DV);
 	AXIS1 LENGTH=4.5in LABEL=(ANGLE=90 HEIGHT=12pt "NM3 RT in msec") ORDER=(0 TO 5000 BY 1000);
	AXIS2 LENGTH=4.5in LABEL=(ANGLE=90 HEIGHT=12pt "NM3 RT in msec") ORDER=(0 TO 7000 BY 1000);
* Settings for X-axis;
 	AXIS3 LENGTH=4.5in LABEL=(HEIGHT=12pt "Session") ORDER=(1 TO 6 BY 1);
 * Plot Y*X=separate person, start axes at 0 unless otherwise specified;
 	PLOT nm3rt*session=ID / VZERO HZERO NOLEGEND VAXIS=AXIS1 HAXIS=AXIS3;  
	PLOT nm5rt*session=ID / VZERO HZERO NOLEGEND VAXIS=AXIS2 HAXIS=AXIS3; 
RUN; QUIT; TITLE1;

* Close rich text file;
ODS RTF CLOSE;

